# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['django_unicorn',
 'django_unicorn.components',
 'django_unicorn.management.commands',
 'django_unicorn.templatetags',
 'django_unicorn.views',
 'django_unicorn.views.action_parsers']

package_data = \
{'': ['*'],
 'django_unicorn': ['static/unicorn/js/*',
                    'static/unicorn/js/morphdom/2.6.1/*',
                    'templates/unicorn/*']}

install_requires = \
['beautifulsoup4>=4.8.0',
 'cachetools>=4.1.1,<5.0.0',
 'decorator>=4.4.2,<5.0.0',
 'django>=2.2',
 'orjson>=3.6.0,<4.0.0',
 'shortuuid>=1.0.1,<2.0.0']

extras_require = \
{':python_version < "3.7"': ['dataclasses>=0.8.0,<0.9.0'],
 'docs': ['Sphinx>=4.3.2,<5.0.0',
          'linkify-it-py>=1.0.3,<2.0.0',
          'myst-parser>=0.16.1,<0.17.0',
          'furo>=2021.11.23,<2022.0.0',
          'sphinx-copybutton>=0.4.0,<0.5.0',
          'sphinx-autobuild>=2021.3.14,<2022.0.0',
          'rst2pdf>=0.98,<0.99'],
 'minify': ['htmlmin>=0.1.12,<0.2.0']}

setup_kwargs = {
    'name': 'django-unicorn',
    'version': '0.51.0',
    'description': 'A magical full-stack framework for Django.',
    'long_description': '<p align="center">\n  <a href="https://www.django-unicorn.com/"><img src="img/unicorn-logo.png" alt="django-unicorn logo" height="200"/></a>\n</p>\n\n<h1 align="center">\n  <a href="https://www.django-unicorn.com/">Unicorn</a>\n  <p>The magical reactive component framework for Django ✨</p>\n</h1>\n\n![PyPI](https://img.shields.io/pypi/v/django-unicorn?color=blue&style=flat-square)\n![PyPI - Downloads](https://img.shields.io/pypi/dm/django-unicorn?color=blue&style=flat-square)\n![GitHub Sponsors](https://img.shields.io/github/sponsors/adamghill?color=blue&style=flat-square)\n[![All Contributors](https://img.shields.io/badge/all_contributors-17-orange.svg?style=flat-square)](#contributors-)\n<!-- ALL-CONTRIBUTORS-BADGE - Do not remove or modify above line -->\n\n[Unicorn](https://www.django-unicorn.com) adds modern reactive component functionality to your Django templates without having to learn a new templating language or fight with complicated JavaScript frameworks. It seamlessly extends Django past its server-side framework roots without giving up all of its niceties or forcing you to re-building your application. With Django Unicorn, you can quickly and easily add rich front-end interactions to your templates, all while using the power of Django.\n\n## ⚡ Getting started\n\n### 1. [Install the package](https://www.django-unicorn.com/docs/installation/)\n\n`pip install django-unicorn` OR `poetry add django-unicorn`\n\n### 2. Add `django_unicorn` to `INSTALLED_APPS`\n\n```python\n# settings.py\nINSTALLED_APPS = (\n    # other apps\n    "django_unicorn",\n)\n```\n\n### 3. Update urls.py\n\n```python\n# urls.py\nimport django_unicorn\n\nurlpatterns = (\n    # other urls\n    path("unicorn/", include("django_unicorn.urls")),\n)\n```\n\n### 4. Add `Unicorn` to the HTML template\n\n```html\n<!-- template.html -->\n{% load unicorn %}\n\n<html>\n  <head>\n    {% unicorn_scripts %}\n  </head>\n  <body>\n    {% csrf_token %}\n  </body>\n</html>\n```\n\n### 5. [Create a component](https://www.django-unicorn.com/docs/components/)\n\n`python manage.py startunicorn COMPONENT_NAME`\n\n`Unicorn` uses the term "component" to refer to a set of interactive functionality that can be put into templates. A component consists of a Django HTML template and a Python view class which contains the backend code. After running the management command, two new files will be created:\n\n- `your_app/templates/unicorn/COMPONENT_NAME.html` (component template)\n- `your_app/components/COMPONENT_NAME.py` (component view)\n\n### 6. Add the component to your template\n\n```html\n<!-- template.html -->\n{% load unicorn %}\n\n<html>\n  <head>\n    {% unicorn_scripts %}\n  </head>\n  <body>\n    {% csrf_token %}\n\n    {% unicorn \'COMPONENT_NAME\' %}\n  </body>\n</html>\n```\n\n## [Example todo component](https://www.django-unicorn.com/examples/todo)\n\nThe `unicorn:` attributes bind the element to data and can also trigger methods by listening for events, e.g. `click`, `input`, `keydown`, etc.\n\n```html\n<!-- ../templates/unicorn/todo.html -->\n\n<div>\n  <form unicorn:submit.prevent="add">\n    <input type="text"\n      unicorn:model.defer="task"\n      unicorn:keyup.escape="task=\'\'"\n      placeholder="New task" id="task"></input>\n  </form>\n  <button unicorn:click="add">Add</button>\n  <button unicorn:click="$reset">Clear all tasks</button>\n\n  <p>\n    {% if tasks %}\n      <ul>\n        {% for task in tasks %}\n          <li>{{ task }}</li>\n        {% endfor %}\n      </ul>\n    {% else %}\n      No tasks 🎉\n    {% endif %}\n  </p>\n</div>\n```\n\n```python\n# ../components/todo.py\n\nfrom django_unicorn.components import UnicornView\nfrom django import forms\n\nclass TodoForm(forms.Form):\n    task = forms.CharField(min_length=2, max_length=20, required=True)\n\nclass TodoView(UnicornView):\n    task = ""\n    tasks = []\n\n    def add(self):\n        if self.is_valid():\n            self.tasks.append(self.task)\n            self.task = ""\n```\n\n## ✨ Wait, is this magic?\n\nSort of! At least it might feel like it. 🤩\n\n1. `Unicorn` progressively enhances a normal Django view, so the initial render is fast and great for SEO.\n2. `Unicorn` binds to the elements you specify and automatically makes AJAX calls when needed.\n3. `Unicorn` seamlessly updates the DOM when the HTML changes.\n\nFocus on building regular Django templates and Python classes without needing to switch to another language or use unnecessary infrastructure.\n\n## 🤯 But wait, there\'s more!\n\nAs if that wasn\'t enough, other features include:\n\n- [Form Validation](https://www.django-unicorn.com/docs/validation/)\n- [Redirection](https://www.django-unicorn.com/docs/redirecting/)\n- [Loading States](https://www.django-unicorn.com/docs/loading-states/)\n- [Dirty States](https://www.django-unicorn.com/docs/dirty-states/)\n- [Partial Updates](https://www.django-unicorn.com/docs/partial-updates/)\n- [Polling](https://www.django-unicorn.com/docs/polling/)\n- [Scroll Triggering](https://www.django-unicorn.com/docs/visibility/)\n- [Messages](https://www.django-unicorn.com/docs/messages/)\n- [Javascript Integration](https://www.django-unicorn.com/docs/advanced/)\n\n## 📖 Dig In\n\n- [Documentation](https://www.django-unicorn.com/docs/)\n- [Examples](https://www.django-unicorn.com/examples/todo)\n- [Screencasts](https://www.django-unicorn.com/screencasts/installation)\n- [Changelog](https://www.django-unicorn.com/docs/changelog/)\n\n## ❤️ Support\n\nThis project is supported by GitHub [Sponsors](https://github.com/sponsors/adamghill) and [Digital Ocean](https://m.do.co/c/617d629f56c0).\n\n<p>\n  <a href="https://m.do.co/c/617d629f56c0">\n    <img src="https://opensource.nyc3.cdn.digitaloceanspaces.com/attribution/assets/SVG/DO_Logo_horizontal_blue.svg" width="201px">\n  </a>\n</p>\n\n## 🔧 Contributors\n\nCheck out [this guide](DEVELOPING.md) for more details on how to contribute.\n\nThanks to the following wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)) who have helped build `Unicorn`.\n\n<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->\n<!-- prettier-ignore-start -->\n<!-- markdownlint-disable -->\n<table>\n  <tbody>\n    <tr>\n      <td align="center" valign="top" width="14.28%"><a href="https://adamghill.com"><img src="https://avatars0.githubusercontent.com/u/317045?v=4?s=100" width="100px;" alt="Adam Hill"/><br /><sub><b>Adam Hill</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=adamghill" title="Code">💻</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=adamghill" title="Tests">⚠️</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://python3.ninja"><img src="https://avatars1.githubusercontent.com/u/44167?v=4?s=100" width="100px;" alt="Andres Vargas"/><br /><sub><b>Andres Vargas</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=zodman" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="http://iskra.ml"><img src="https://avatars3.githubusercontent.com/u/6555851?v=4?s=100" width="100px;" alt="Eddy Ernesto del Valle Pino"/><br /><sub><b>Eddy Ernesto del Valle Pino</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=edelvalle" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://www.linkedin.com/in/yaser-al-najjar-429b9096/"><img src="https://avatars3.githubusercontent.com/u/10493809?v=4?s=100" width="100px;" alt="Yaser Al-Najjar"/><br /><sub><b>Yaser Al-Najjar</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=yaseralnajjar" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/sbidy"><img src="https://avatars.githubusercontent.com/u/1077364?v=4?s=100" width="100px;" alt="Stephan Traub"/><br /><sub><b>Stephan Traub</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=sbidy" title="Tests">⚠️</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/frbor"><img src="https://avatars.githubusercontent.com/u/2320183?v=4?s=100" width="100px;" alt="Fredrik Borg"/><br /><sub><b>Fredrik Borg</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=frbor" title="Code">💻</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=frbor" title="Tests">⚠️</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/mbacicc"><img src="https://avatars.githubusercontent.com/u/46646960?v=4?s=100" width="100px;" alt="mbacicc"/><br /><sub><b>mbacicc</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=mbacicc" title="Code">💻</a></td>\n    </tr>\n    <tr>\n      <td align="center" valign="top" width="14.28%"><a href="http://ambient-innovation.com"><img src="https://avatars.githubusercontent.com/u/3176075?v=4?s=100" width="100px;" alt="Ron"/><br /><sub><b>Ron</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=GitRon" title="Documentation">📖</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Franziskhan"><img src="https://avatars.githubusercontent.com/u/86062014?v=4?s=100" width="100px;" alt="Franziskhan"/><br /><sub><b>Franziskhan</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=Franziskhan" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/joshiggins"><img src="https://avatars.githubusercontent.com/u/5124298?v=4?s=100" width="100px;" alt="Josh Higgins"/><br /><sub><b>Josh Higgins</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=joshiggins" title="Tests">⚠️</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=joshiggins" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/MayasMess"><img src="https://avatars.githubusercontent.com/u/51958712?v=4?s=100" width="100px;" alt="Amayas Messara"/><br /><sub><b>Amayas Messara</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=MayasMess" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="http://www.apoorvapandey.com"><img src="https://avatars.githubusercontent.com/u/21103831?v=4?s=100" width="100px;" alt="Apoorva Pandey"/><br /><sub><b>Apoorva Pandey</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=apoorvaeternity" title="Tests">⚠️</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=apoorvaeternity" title="Code">💻</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="http://www.nerdocs.at"><img src="https://avatars.githubusercontent.com/u/2955584?v=4?s=100" width="100px;" alt="Christian González"/><br /><sub><b>Christian González</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=nerdoc" title="Code">💻</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=nerdoc" title="Documentation">📖</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/robwa"><img src="https://avatars.githubusercontent.com/u/4658937?v=4?s=100" width="100px;" alt="robwa"/><br /><sub><b>robwa</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=robwa" title="Code">💻</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=robwa" title="Tests">⚠️</a></td>\n    </tr>\n    <tr>\n      <td align="center" valign="top" width="14.28%"><a href="https://medium.com/@pbadeer"><img src="https://avatars.githubusercontent.com/u/467756?v=4?s=100" width="100px;" alt="Preston Badeer"/><br /><sub><b>Preston Badeer</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=pbadeer" title="Documentation">📖</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/stat1c-void"><img src="https://avatars.githubusercontent.com/u/9142081?v=4?s=100" width="100px;" alt="Sergei"/><br /><sub><b>Sergei</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=stat1c-void" title="Documentation">📖</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=stat1c-void" title="Code">💻</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=stat1c-void" title="Tests">⚠️</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/bazubii"><img src="https://avatars.githubusercontent.com/u/12039914?v=4?s=100" width="100px;" alt="bazubii"/><br /><sub><b>bazubii</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=bazubii" title="Code">💻</a> <a href="https://github.com/adamghill/django-unicorn/commits?author=bazubii" title="Tests">⚠️</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://github.com/dancaron"><img src="https://avatars.githubusercontent.com/u/535851?v=4?s=100" width="100px;" alt="Dan Caron"/><br /><sub><b>Dan Caron</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=dancaron" title="Documentation">📖</a></td>\n      <td align="center" valign="top" width="14.28%"><a href="https://hauntsaninja.github.io/"><img src="https://avatars.githubusercontent.com/u/12621235?v=4?s=100" width="100px;" alt="Shantanu"/><br /><sub><b>Shantanu</b></sub></a><br /><a href="https://github.com/adamghill/django-unicorn/commits?author=hauntsaninja" title="Code">💻</a></td>\n    </tr>\n  </tbody>\n</table>\n\n<!-- markdownlint-restore -->\n<!-- prettier-ignore-end -->\n\n<!-- ALL-CONTRIBUTORS-LIST:END -->\n\nThis project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!\n',
    'author': 'Adam Hill',
    'author_email': 'unicorn@adamghill.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://www.django-unicorn.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<4',
}


setup(**setup_kwargs)
